import unittest

from bdi.sources.uta0_pg import UTA0

import hgvs.parser
import hgvs.hgvsmapper

class Test_HGVSMapper(unittest.TestCase):
    def setUp(self):
        self.bdi = UTA0()
        self.hm = hgvs.hgvsmapper.HGVSMapper(self.bdi, cache_transcripts=True)
        self.hp = hgvs.parser.Parser()

    def test_1(self):
        # From garcia.tsv:
        # AOAH    NM_001177507.1:c.1486G>A      
        hgvs_g = 'NC_000007.13:g.36561662C>T'
        hgvs_c = 'NM_001637.3:c.1582G>A'
    
        var_g = self.hp.parse_hgvs_variant(hgvs_g)
        var_c = self.hm.hgvsg_to_hgvsc( var_g, 'NM_001637.3' )

        self.assertEqual( str(var_c) , hgvs_c )


if __name__ == '__main__':
    unittest.main()

## <LICENSE>
## Copyright 2014 HGVS Contributors (https://bitbucket.org/invitae/hgvs)
## 
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
## 
##     http://www.apache.org/licenses/LICENSE-2.0
## 
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
## </LICENSE>



"""
stopgap -- components that need to be fleshed out later

importing stopgap should tell you that you're using incomplete and/or unstable code
"""

import gzip
import json
from pkg_resources import resource_filename

from Bio.SeqUtils.CheckSum import seguid

seguid_acs = json.loads(gzip.open(resource_filename(__name__,'/data/seguid-acs.json.gz')).read())

def pseq_to_acs(seq):
    "return accessions (0 or more) for a given protein sequence"
    seq = seq.rstrip('*')
    hash = seguid(seq)
    try:
        return seguid_acs[hash]
    except KeyError:
        return 'SEGUID_' + hash

def pseq_to_ac(seq):
    "return accession for a given protein sequence, or None"
    try:
        return pseq_to_acs(seq)[0]
    except IndexError:
        return None
    

## <LICENSE>
## Copyright 2014 HGVS Contributors (https://bitbucket.org/invitae/hgvs)
## 
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
## 
##     http://www.apache.org/licenses/LICENSE-2.0
## 
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
## </LICENSE>



#
# c to p tests - cvid subset plus some additional tests (from Emily Hare)
#
import os
import unittest

import test_hgvs_hgvsmapper_cp_base

class TestHgvsCToPSubsetCvidsPlus(test_hgvs_hgvsmapper_cp_base.TestHgvsCToPBase):

    def test_hgvsc_to_hgvsp_cvid_subset_plus(self):
        infilename = 'cvid_subset_plus.tsv'
        outfilename = 'cvid_subset_plus.out'
        infile = os.path.join(os.path.dirname(__file__), 'data', infilename)
        outfile = os.path.join(os.path.dirname(__file__), 'data', outfilename)
        self._run_cp_test(infile, outfile)


if __name__ == '__main__':
    unittest.main()
## <LICENSE>
## Copyright 2014 HGVS Contributors (https://bitbucket.org/invitae/hgvs)
## 
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
## 
##     http://www.apache.org/licenses/LICENSE-2.0
## 
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
## </LICENSE>
